#
# spec file for package opencv
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_with ffmpeg

Name:           opencv
%define libname lib%{name}
%define soname  2_4
Version:        2.4.1
Release:        2.2.1
Summary:        Collection of algorithms for computer vision
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
Url:            http://%{name}.willowgarage.com/wiki/
Source0:        http://downloads.sourceforge.net/project/%{name}library/%{name}-unix/%{version}/OpenCV-%{version}.tar.bz2
# PATCH-FIX-UPSTREAM opencv-samples.patch koprok@nand.bg -- Improve samples installation.
Patch1:         %{name}-samples.patch
# PATCH-FIX-UPSTREAM opencv-underlinking.patch koprok@nand.bg -- Make libopencv_highgui.so link to libv4l2 since it's using symbols defined there.
Patch2:         %{name}-underlinking.patch
# PATCH-FIX-OPENSUSE opencv-datadir.patch koprok@nand.bg -- Install data files in share/opencv instead of share/OpenCV.
Patch3:         %{name}-datadir.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  OpenEXR-devel
BuildRequires:  cmake
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  gstreamer-0_10-plugins-base-devel
BuildRequires:  libdc1394-devel
BuildRequires:  libeigen2-devel
BuildRequires:  libjasper-devel
BuildRequires:  libqt4-devel
#BuildRequires:  libucil-devel
#BuildRequires:  libunicap-devel
BuildRequires:  libilmbase-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libtiff-devel
BuildRequires:  libxine-devel
BuildRequires:  python-devel
BuildRequires:  python-numpy-devel
BuildRequires:  zlib-devel
%if %{with ffmpeg}
BuildRequires:  libffmpeg-devel
%endif
BuildRequires:  libv4l-devel

%description
OpenCV means Intel® Open Source Computer Vision Library. It is a collection of C
functions and a few C++ classes that implement some popular Image Processing and
Computer Vision algorithms.

%package -n %{libname}%{soname}
Summary:        Development files for using the OpenCV library
Group:          Development/Libraries/C and C++

%description -n %{libname}%{soname}
The Open Computer Vision Library is a collection of algorithms and sample code
for various computer vision problems. The library is compatible with IPL and
utilizes Intel Integrated Performance Primitives for better performance.

%package devel
Summary:        Development files for using the OpenCV library
Group:          Development/Libraries/C and C++
Requires:       %{libname}%{soname} = %{version}
Requires:       %{name} = %{version}

%description devel
This package contains the OpenCV C/C++ library and header files, as well as
documentation. It should be installed if you want to develop programs that will
use the OpenCV library.

%package -n python-%{name}
Summary:        Python bindings for apps which use OpenCV
Group:          Development/Libraries/Python
Requires:       python-base = %{py_ver}
%py_requires

%description -n python-%{name}
This package contains Python bindings for the OpenCV library.

%package -n %{name}-doc
Summary:        Documentation and examples for OpenCV
Group:          Development/Libraries/C and C++
Recommends:     python
# Since this package also contains examples that need -devel to be compiled
Recommends:     %{name}-devel

%description -n %{name}-doc
This package contains the documentation and examples for the OpenCV library.

%prep
%setup -qn OpenCV-%{version}
%patch1 -p1
%patch2 -p1
%patch3 -p1

# Windows specific and with wrong end of line
rm -f doc/packaging.txt
chmod +x samples/c/build_all.sh
sed -i 's/\r$//' samples/c/adaptiveskindetector.cpp \
                 samples/c/latentsvmdetect.cpp \
                 samples/gpu/hog.cpp \
                 samples/python/camshift.py

%build
export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags}"
mkdir build
cd build
cmake -DCMAKE_BUILD_TYPE=Release \
      -DCMAKE_INSTALL_PREFIX='%{_prefix}' \
      -DCMAKE_SKIP_RPATH=ON \
      -DBUILD_TESTS=OFF \
      -DINSTALL_C_EXAMPLES=ON \
      -DINSTALL_PYTHON_EXAMPLES=ON \
      -DLIB_SUFFIX=$(echo %{_lib} | cut -b4-) \
      -DENABLE_OMIT_FRAME_POINTER=OFF \
      -DWITH_QT=ON \
      -DWITH_OPENGL=ON \
      -DWITH_UNICAP=ON \
      -DWITH_XINE=ON \
       ..
make %{?_smp_mflags} VERBOSE=1

%install
cd build
make DESTDIR=%{?buildroot:%{buildroot}} install/fast
mkdir -p %{buildroot}%{_docdir}
mv %{buildroot}%{_datadir}/%{name}/doc %{buildroot}%{_docdir}/%{name}-doc
mv %{buildroot}%{_datadir}/%{name}/samples %{buildroot}%{_docdir}/%{name}-doc/examples
dos2unix %{buildroot}%{_docdir}/%{name}-doc/examples/python*/*.py
dos2unix %{buildroot}%{_docdir}/%{name}-doc/examples/gpu/*.cpp
%fdupes -s %{buildroot}%{_docdir}/%{name}-doc/examples

%clean
rm -rf %{buildroot}

%post   -n %{libname}%{soname} -p /sbin/ldconfig

%postun -n %{libname}%{soname} -p /sbin/ldconfig

%files -n %{libname}%{soname}
%defattr(-, root, root, 0755)
%{_libdir}/lib*.so.*

%files -n %{name}
%defattr(0644, root, root, 0755)
%attr(0755, root, root) %{_bindir}/%{name}_*
%{_datadir}/%{name}
%exclude %{_datadir}/%{name}/OpenCVConfig*.cmake

%files devel
%defattr(0644, root, root, 0755)
%{_includedir}/opencv
%{_includedir}/opencv2
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/%{name}.pc
%{_datadir}/%{name}/OpenCVConfig*.cmake

%files -n python-%{name}
%defattr(0644, root, root, 0755)
%{python_sitearch}/cv.py
%{python_sitearch}/cv2.so

%files -n %{name}-doc
%defattr(-, root, root, 0755)
%{_docdir}/%{name}-doc

%changelog
* Fri Jun  8 2012 koprok@nand.bg
- Update to OpenCV 2.4.1
  More info at:
  http://code.opencv.org/projects/opencv/wiki/ChangeLog
* Tue May 15 2012 koprok@nand.bg
- Update to OpenCV 2.4.0
  More info at:
  http://code.opencv.org/projects/opencv/wiki/ChangeLog
* Sat Mar 17 2012 dimstar@opensuse.org
- Add opencv-gcc47.patch: Fix build with gcc 4.7.
* Tue Jan 10 2012 crrodriguez@opensuse.org
- Use Explicit Buildrequires on several needed libraries
  future dependency cleanups may/will cause build to fail otherwise.
* Sat Dec 31 2011 idonmez@suse.com
- Add upstream r6881 to fix clang compatibility
* Tue Oct 18 2011 coolo@suse.com
- uncomment libraries not in 12.1 for now
* Fri Oct  7 2011 toddrme2178@gmail.com
- Changed groups (fix for RPMLINT warning)
- Added check for duplicate files (fix for RPMLINT warning)
- Added py_requires macros and python-base dependencies (fix for RPMLINT warning)
- Escaped macros (fix for RPMLINT warning)
- Fixed end-of-line encoding problems (fix for RPMLINT warning)
- Added libeigen2-devel buildrequires
- Added libunicap and libucil buildrequires (libunicap supports requires libucil)
- Cleaned up spec file formatting
* Tue Aug 23 2011 koprok@nand.bg
- Dropped opencv-2.3-ffmpeg.patch, applied upstream
* Tue Aug 23 2011 koprok@nand.bg
- Revive opencv-2.3-ffmpeg.patch, needs rebase
- Tag all patches according to openSUSE packaging guidelines
* Tue Aug 23 2011 koprok@nand.bg
- Removed opencv-2.3-cmake.patch, old cmake cannot be used any more.
- Python bindings cannot be built without NumPy any more.
* Fri Aug 19 2011 koprok@nand.bg
- Update to OpenCV 2.3.1
* Thu Aug 18 2011 reddwarf@opensuse.org
- Update and readd opencv-2.3-underlinking.patch since it is still
  necessary.
* Wed Aug 17 2011 reddwarf@opensuse.org
- Fix support for new ffmpeg versions
* Sun Aug 14 2011 koprok@nand.bg
- Removed unnecessary patches
- Enable Python NumPy support on openSUSE 11.2
- Build Qt instead of Gtk GUI
- Fix cmake files for openSUSE 11.1
- No GStreamer support on openSUSE 11.1
* Fri Aug 12 2011 koprok@nand.bg
- Update to OpenCV 2.3.0.
  More info at:
  http://opencv.willowgarage.com/wiki/OpenCV%%20Change%%20Logs
* Wed Aug  3 2011 koprok@nand.bg
- Fix build on openSUSE 11.2
* Wed Jul  6 2011 idonmez@novell.com
- Add opencv-v4l-2.6.38.patch: use the new libv4l2 interface
* Mon Dec 27 2010 koprok@nand.bg
- Enable Python NumPy support
- SWIG is not required any more
- Enable OpenEXR support
* Thu Dec 23 2010 koprok@nand.bg
- Update to OpenCV 2.2.0.
  More info at:
  http://opencv.willowgarage.com/wiki/OpenCV%%20Change%%20Logs
* Sun Dec 12 2010 cristian.rodriguez@opensuse.org
- Use system zlib, oh, and do not export ZLIB symbols to
  other applications, clashes ensued.
* Thu Nov 11 2010 dmueller@suse.de
- fix build with gcc 4.6
* Fri Oct  8 2010 reddwarf@opensuse.org
- add -underlinking patch
* Thu Apr 22 2010 koprok@nand.bg
- devel package renamed to opencv-devel, so that switching between
  OBS and packman opencv packages is easier
* Mon Apr 19 2010 koprok@nand.bg
- fix gstreamer support
- fix xine support
- fix some rpmlint warnings
- fix shared libraries permissions
* Sat Apr 17 2010 koprok@nand.bg
- Do not waste resources building the tests as we do not run them
* Fri Apr 16 2010 koprok@nand.bg
- Do not disable SSE,SSE2,etc. According to OpenCV changelog,
  it should be safe to leave these enabled.
* Thu Apr 15 2010 koprok@nand.bg
- fix build on openSUSE 11.0
* Tue Apr 13 2010 koprok@nand.bg
- Update to OpenCV 2.1.0:
  * The whole OpenCV is now using exceptions instead of the old
    libc-style mechanism
  * Experimental "static" OpenCV configuration in CMake was
    contributed by Jose Luis Blanco.
    Pass "BUILD_SHARED_LIBS=OFF" to CMake to build OpenCV statically.
  * new improved version of one-way descriptor is added
  * User can now control the image areas visible after the stereo
    rectification
  * Fullscreen has been added (thanks to Yannick Verdie).
  * Further info at:
    http://opencv.willowgarage.com/wiki/OpenCV%%20Change%%20Logs
* Wed Apr  7 2010 coolo@novell.com
- fix build with libpng14
* Thu Mar 18 2010 coolo@novell.com
- small spec file cleanup
* Sat Jan 16 2010 tittiatcoke@gmail.com
- Moved to the KDE repositories to enable inclusion in kipi-plugins
* Fri Oct  9 2009 cmorve69@yahoo.es
- Initial package
